OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Das Schreiben in das „config“-Verzeichnis ist nicht möglich!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Wenn Sie jedoch möchten, dass die Datei config.php schreibgeschützt bleiben soll, dann setzen Sie die Option \"config_is_read_only\" in der Datei auf true.",
    "See %s" : "Siehe %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Die Dateien der App %1$s wurden nicht korrekt ersetzt. Stellen Sie sicher, dass es sich um eine mit dem Server kompatible Version handelt.",
    "Sample configuration detected" : "Beispielkonfiguration gefunden",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es wurde festgestellt, dass die Beispielkonfiguration kopiert wurde. Dies kann Ihre Installation zerstören und wird nicht unterstützt. Bitte die Dokumentation lesen, bevor Änderungen an der config.php vorgenommen werden.",
    "%s email verification" : "%s E-Mail-Überprüfung",
    "Email verification" : "E-Mail-Überprüfung",
    "Click the following button to confirm your email." : "Klicken Sie auf die folgende Schaltfläche, um Ihre E-Mail zu bestätigen.",
    "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken um Ihre E-Mail-Adresse zu bestätigen",
    "Confirm your email" : "Ihre E-Mail-Adresse bestätigen",
    "Other activities" : "Andere Aktivitäten",
    "%1$s and %2$s" : "%1$s und %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s und %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s und %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s und %5$s",
    "Education Edition" : "Bildungsausgabe",
    "Enterprise bundle" : "Firmen-Paket",
    "Groupware bundle" : "Groupware-Paket",
    "Hub bundle" : "Hub-Paket",
    "Social sharing bundle" : "Paket für das Teilen in sozialen Medien",
    "PHP %s or higher is required." : "PHP %s oder höher wird benötigt.",
    "PHP with a version lower than %s is required." : "PHP wird in einer früheren Version als %s benötigt.",
    "%sbit or higher PHP required." : "%sbit oder höheres PHP wird benötigt.",
    "The following architectures are supported: %s" : "Folgende Architekturen werden unterstützt: %s",
    "The following databases are supported: %s" : "Folgende Datenbanken werden unterstützt: %s",
    "The command line tool %s could not be found" : "Das Kommandozeilenwerkzeug %s konnte nicht gefunden werden",
    "The library %s is not available." : "Die Bibliothek %s ist nicht verfügbar.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Die Bibliothek %1$s wird in einer neueren Version als %2$s benötigt - verfügbare Version ist %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Die Bibliothek %1$s wird in einer früheren Version als %2$s benötigt - verfügbare Version ist %3$s.",
    "The following platforms are supported: %s" : "Folgende Plattformen werden unterstützt: %s",
    "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
    "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Der angemeldete Benutzer muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen. ",
    "Logged in user must be an admin or sub admin" : "Der angemeldete Benutzer muss ein (Sub-)Administrator sein",
    "Logged in user must be an admin" : "Der angemeldete Benutzer muss ein Administrator sein",
    "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
    "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
    "»%s« started remote wipe" : "»%s« hat das Löschen aus der Ferne gestartet",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Gerät oder Anwendung »%s« hat den Vorgang des Löschens aus der Ferne gestartet. Sie bekommen eine weitere E-Mail sobald der Vorgang beendet wurde",
    "Wiping of device %s has finished" : "Löschen von Gerät %s wurde beendet",
    "Wiping of device »%s« has finished" : "Löschen von Gerät »%s« wurde beendet",
    "»%s« finished remote wipe" : "»%s« hat das Löschen aus der Ferne beendet",
    "Device or application »%s« has finished the remote wipe process." : "Gerät oder Anwendung »%s« hat den Vorgang des Löschens aus der Ferne beendet.",
    "Remote wipe started" : "Fernlöschung gestartet",
    "A remote wipe was started on device %s" : "Eine Fernlöschung wurde am Gerät %s gestartet",
    "Remote wipe finished" : "Fernlöschung fertig",
    "The remote wipe on %s has finished" : "Die Fernlöschung auf %s ist fertig",
    "Authentication" : "Authentifizierung",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "Avatar image is not square" : "Benutzerbild ist nicht quadratisch",
    "View profile" : "Profil ansehen",
    "today" : "Heute",
    "tomorrow" : "Morgen",
    "yesterday" : "Gestern",
    "_in %n day_::_in %n days_" : ["In %n Tag","In %n Tagen"],
    "_%n day ago_::_%n days ago_" : ["Vor %n Tag","Vor %n Tagen"],
    "next month" : "Nächsten Monat",
    "last month" : "Letzten Monat",
    "_in %n month_::_in %n months_" : ["In %n Monat","In %n Monaten"],
    "_%n month ago_::_%n months ago_" : ["Vor %n Monat","Vor %n Monaten"],
    "next year" : "Nächstes Jahr",
    "last year" : "Letztes Jahr",
    "_in %n year_::_in %n years_" : ["In %n Jahr","In %n Jahren"],
    "_%n year ago_::_%n years ago_" : ["Vor %n Jahr","Vor %n Jahren"],
    "_in %n hour_::_in %n hours_" : ["In %n Stunde","In %n Stunden"],
    "_%n hour ago_::_%n hours ago_" : ["Vor %n Stunde","Vor %n Stunden"],
    "_in %n minute_::_in %n minutes_" : ["In %n Minute","In %n Minuten"],
    "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
    "in a few seconds" : "In wenigen Sekunden",
    "seconds ago" : "Gerade eben",
    "Empty file" : "Leere Datei",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID:  %s existiert nicht. Bitte aktivieren Sie es in Ihren Einstellungen oder kontaktieren Sie Ihren Administrator.",
    "File already exists" : "Datei bereits vorhanden",
    "Invalid path" : "Ungültiger Pfad",
    "Failed to create file from template" : "Fehler beim Erstellen der Datei aus Vorlage",
    "Templates" : "Vorlagen",
    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
    "File name is too long" : "Dateiname ist zu lang",
    "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
    "Empty filename is not allowed" : "Ein leerer Dateiname ist nicht erlaubt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Die Anwendung \"%s\" kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Die App \"%s\" kann nicht installiert werden, da sie mit dieser Serverversion nicht kompatibel ist.",
    "__language_name__" : "Deutsch (Förmlich: Sie)",
    "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch versandte E-Mail, bitte nicht antworten.",
    "Help" : "Hilfe",
    "Appearance and accessibility" : "Aussehen und Zugänglichkeit",
    "Apps" : "Apps",
    "Personal settings" : "Persönliche Einstellungen",
    "Administration settings" : "Administrationseinstellungen",
    "Settings" : "Einstellungen",
    "Log out" : "Abmelden",
    "Users" : "Benutzer",
    "Email" : "E-Mail",
    "Mail %s" : "E-Mail %s",
    "Phone" : "Telefon",
    "Call %s" : "%s anrufen",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "%s auf Twitter anzeigen",
    "Website" : "Webseite",
    "Visit %s" : "%s besuchen",
    "Address" : "Adresse",
    "Profile picture" : "Profilbild",
    "About" : "Über",
    "Full name" : "Vollständiger Name",
    "Headline" : "Überschrift",
    "Organisation" : "Organisation",
    "Role" : "Funktion",
    "Unknown user" : "Unbekannter Benutzer",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Enter the database username and name for %s" : "Den Datenbankbenutzernamen und den Namen eingeben für %s",
    "Enter the database username for %s" : "Den Datenbankbenutzernamen eingeben für %s",
    "Enter the database name for %s" : "Den Datenbanknamen eingeben für %s",
    "You cannot use dots in the database name %s" : "Sie dürfen keine Punkte im Datenbanknamen %s verwenden",
    "MySQL username and/or password not valid" : "MySQL-Benutzername und/oder Passwort ungültig",
    "You need to enter details of an existing account." : "Sie müssen Details von einem existierenden Benutzer einfügen.",
    "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
    "Oracle username and/or password not valid" : "Oracle-Benutzername und/oder -Passwort ungültig",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren. Die Benutzung erfolgt auf eigene Gefahr!",
    "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entfernen Sie die open_basedir-Einstellung in Ihrer php.ini oder wechseln Sie zu 64-Bit-PHP.",
    "Set an admin username." : "Einen Administrations-Benutzernamen setzen.",
    "Set an admin password." : "Ein Administrationspasswort setzen.",
    "Cannot create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Freigabe-Backend %s muss in der OCP\\Share_Backend - Schnittstelle implementiert werden",
    "Sharing backend %s not found" : "Freigabe-Backend %s nicht gefunden",
    "Sharing backend for %s not found" : "Freigabe-Backend für %s nicht gefunden",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s hat » %2$s« mit Ihnen geteilt und möchte folgendes hinzufügen:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s hat »%2$s« mit Ihnen geteilt und möchte folgendes hinzufügen",
    "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit Ihnen geteilten Datei hinzugefügt",
    "Open »%s«" : "»%s« öffnen",
    "%1$s via %2$s" : "%1$s über %2$s",
    "You are not allowed to share %s" : "Die Freigabe von %s ist Ihnen nicht erlaubt",
    "Cannot increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
    "Files cannot be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
    "Files cannot be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
    "Expiration date is in the past" : "Das Ablaufdatum liegt in der Vergangenheit.",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Das Ablaufdatum kann nicht mehr als %n Tag in der Zukunft liegen","Das Ablaufdatum kann nicht mehr als %n Tage in der Zukunft liegen"],
    "Sharing is only allowed with group members" : "Teilen ist nur mit Gruppenmitgliedern erlaubt",
    "Sharing %s failed, because this item is already shared with user %s" : "Freigabe von %s fehlgeschlagen, da dieses Element schon mit dem Benutzer %s geteilt wird",
    "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit Ihnen geteilt",
    "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit Ihnen geteilt.",
    "Click the button below to open it." : "Klicken Sie zum Öffnen auf die untere Schaltfläche.",
    "The requested share does not exist anymore" : "Die angeforderte Freigabe existiert nicht mehr",
    "Could not find category \"%s\"" : "Die Kategorie \"%s“ konnte nicht gefunden werden",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "Son.",
    "Mon." : "Mon.",
    "Tue." : "Die.",
    "Wed." : "Mit.",
    "Thu." : "Don.",
    "Fri." : "Fre.",
    "Sat." : "Sam.",
    "Su" : "So",
    "Mo" : "Mo",
    "Tu" : "Di",
    "We" : "Mi",
    "Th" : "Do",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "The user limit has been reached and the user was not created." : "Die Benutzergrenze wurde erreicht und der Benutzer wurde nicht erstellt.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
    "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
    "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
    "Username must not consist of dots only" : "Der Benutzername darf nicht nur aus Punkten bestehen",
    "Username is invalid because files already exist for this user" : "Der Benutzer ist ungültig, da bereits Dateien von diesem Benutzer existieren",
    "A valid password must be provided" : "Es muss ein gültiges Passwort eingegeben werden",
    "The username is already being used" : "Dieser Benutzername existiert bereits",
    "Could not create user" : "Benutzer konnte nicht erstellt werden",
    "User disabled" : "Benutzer deaktiviert",
    "Login canceled by app" : "Anmeldung durch die App abgebrochen",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Die App „%1$s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %2$s",
    "a safe home for all your data" : "ein sicherer Ort für all Ihre Daten",
    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte später erneut versuchen.",
    "Cannot download file" : "Datei kann nicht heruntergeladen werden",
    "Application is not enabled" : "Die Anwendung ist nicht aktiviert",
    "Authentication error" : "Authentifizierungsfehler",
    "Token expired. Please reload page." : "Token abgelaufen. Bitte laden Sie die Seite neu.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Keine Datenbanktreiber (SQLite, MySQL oder PostgreSQL) installiert.",
    "Cannot write into \"config\" directory." : "Es kann nicht in das Verzeichnis \"config\" geschrieben werden.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Oder wenn Sie möchten, dass die Datei config.php schreibgeschützt bleiben soll, dann setzen Sie die Option \"config_is_read_only\" in der Datei auf True. Siehe %s",
    "Cannot write into \"apps\" directory." : "Es kann nicht in das Verzeichnis \"apps\" geschrieben werden.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
    "Cannot create \"data\" directory." : "Kann das \"Daten\"-Verzeichnis nicht erstellen.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können normalerweise korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
    "Your data directory is not writable." : "Ihr Datenverzeichnis ist schreibgeschützt.",
    "Setting locale to %s failed." : "Das Setzen der Sprache (locale) auf %s ist fehlgeschlagen.",
    "Please install one of these locales on your system and restart your web server." : "Bitte installieren Sie eine dieser Sprachen (locales) auf Ihrem System und starten Sie den Webserver neu.",
    "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
    "Please ask your server administrator to install the module." : "Bitte kontaktieren Sie Ihre Server-Administration und bitten Sie um die Installation des Moduls.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung „%s“ ist nicht auf „%s“ gesetzt.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann Ihre Nextcloud wieder lauffähig machen.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 ist mindestestens erforderlich. Im Moment ist %s installiert.",
    "To fix this issue update your libxml2 version and restart your web server." : "Um den Fehler zu beheben, müssen Sie die libxml2 Version aktualisieren und den Webserver neustarten.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
    "Please ask your server administrator to restart the web server." : "Bitte kontaktieren Sie Ihre Server-Administration und bitten Sie um den Neustart des Webservers.",
    "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Bitten Sie Ihre Server-Administration, die Nextcloud-Konfiguration zu überprüfen.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 benötigt.",
    "Please upgrade your database version." : "Bitte aktualisieren Sie Ihre Datenbankversion.",
    "Your data directory is readable by other users." : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändern Sie die Berechtigungen auf 0770, so dass das Verzeichnis nicht von anderen Benutzern angezeigt werden kann.",
    "Your data directory must be an absolute path." : "Ihr Datenverzeichnis muss einen absoluten Pfad haben.",
    "Check the value of \"datadirectory\" in your configuration." : "Überprüfen Sie den Wert von „datadirectory“ in Ihrer Konfiguration.",
    "Your data directory is invalid." : "Ihr Datenverzeichnis ist ungültig.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stellen Sie sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des Datenverzeichnisses existiert.",
    "Action \"%s\" not supported or implemented." : "Aktion \"%s\" wird nicht unterstützt oder ist nicht implementiert.",
    "Authentication failed, wrong token or provider ID given" : "Authentifizierung ist fehlgeschlagen. Falsches Token oder Provider-ID wurde übertragen.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Es fehlen Parameter um die Anfrage zu bearbeiten. Fehlende Parameter: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" wird bereits von Cloud-Federation-Provider \"%2$s\" verwendet.",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud-Federation-Provider mit ID: \"%s\" ist nicht vorhanden.",
    "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf „%s“ konnte nicht ermittelt werden.",
    "Storage unauthorized. %s" : "Speicher nicht autorisiert. %s",
    "Storage incomplete configuration. %s" : "Speicher-Konfiguration unvollständig. %s",
    "Storage connection error. %s" : "Verbindungsfehler zum Speicherplatz. %s",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
    "This can usually be fixed by giving the webserver write access to the config directory." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das config-Verzeichnis gegeben wird.",
    "%s enter the database username and name." : "%s geben Sie den Datenbank-Benutzernamen  und den Datenbanknamen an.",
    "%s enter the database username." : "%s geben Sie den Datenbank-Benutzernamen an.",
    "%s enter the database name." : "%s geben Sie den Datenbanknamen an.",
    "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
    "Cannot read file" : "Datei kann nicht gelesen werden",
    "Cannot write into \"config\" directory" : "Schreiben in das „config“-Verzeichnis ist nicht möglich",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
    "Cannot write into \"apps\" directory" : "Schreiben in das „apps“-Verzeichnis ist nicht möglich",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
    "Cannot create \"data\" directory" : "Kann das \"Daten\"-Verzeichnis nicht erstellen.",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden indem dem Web-Server Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
    "Setting locale to %s failed" : "Das Setzen der Umgebungslokale auf %s ist fehlgeschlagen",
    "Please install one of these locales on your system and restart your webserver." : "Bitte installieren Sie eine dieser Sprachen auf Ihrem System und starten Sie den Webserver neu.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ist nicht auf den erwarteten Wert „0“, sondern stattdessen  auf „%s“ gesetzt",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bitte setzen Sie zum Beheben dieses Problems <code>mbstring.func_overload</code> in Ihrer php.ini auf <code>0</code>.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
    "Please upgrade your database version" : "Bitte aktualisieren Sie Ihre Datenbankversion",
    "Your data directory is readable by other users" : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden",
    "Your data directory must be an absolute path" : "Ihr Datenverzeichnis muss einen eindeutigen Pfad haben",
    "Check the value of \"datadirectory\" in your configuration" : "Überprüfen Sie bitte die Angabe unter „datadirectory“ in Ihrer Konfiguration",
    "Your data directory is invalid" : "Ihr Datenverzeichnis ist ungültig."
},
"nplurals=2; plural=(n != 1);");
